@@ -34,10 +34,10 @@ class BGEditor():
             return lyric.make()
         return None
 
-    def create_video_json(self, list_comp_data, job_id):
+    def create_video_json(self, list_comp_data, job_id, mf_server="http://api-magicframe.automusic.win/"):
         #path_vid = self.root_dir.name + "/final-vid-" + str(uuid.uuid4()) + ".avi"
         path_vid = get_dir('results') + "final-vid-" + str(uuid.uuid4()) + ".mp4"
-        create_video(list_comp_data, path_vid, job_id)
+        path_vid = create_video(list_comp_data, path_vid, job_id, mf_server)
         return path_vid
 
     def close(self):
