@@ -11,7 +11,11 @@ def upload_file(path):
     public_folder_id = "1kl75TP6zJiuFBdjhJUw1GHhdcIEjueoE"
     file_name = os.path.basename(path)
     return Client("/u02/drive_config/public_config/coca_idrive.json", "upload", path, "").upload_file(file_name,path, public_folder_id)
-
+def remove(path):
+    try:
+        os.remove(path)
+    except:
+        pass
 def download_file(url, root_dir=None, ext= None):
     dh = DriverHelper()
     return dh.download_file(url, root_dir, ext)
