@@ -126,7 +126,12 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
             max_duration = comp.duration + comp.start_time
         if comp.real_duration + comp.start_time > max_real_duration:
             max_real_duration = comp.real_duration + comp.start_time
-
+    if intro_time_real <= 0:
+        for item in arr_composite_no_intro:
+            tmp_start=item.start - intro_time_real
+            if tmp_start <0:
+                tmp_start=0
+            item.set_start(tmp_start)
     logger = MyBarLogger(job_id, mf_server)
     if not is_compilation:
         final_clip = CompositeVideoClip(arr_composite).subclip(0, max_duration)
@@ -135,7 +140,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     else:
         if audio_compilation_path is None:
             raise Exception("Audio Compilation Error!!!")
-        cnt_real_duration=1
+        cnt_real_duration = 1
         while max_real_duration < 60*2/3 and cnt_real_duration<2 and cnt_effect_vid>1:
             max_real_duration*=2
             cnt_real_duration+=1
@@ -239,15 +244,18 @@ class Component:
         self.get_audio()
         rs = self.get_clip()
         if self.audio_moviepy:
-           rs = rs.set_audio(self.audio_moviepy)
+          rs = rs.set_audio(self.audio_moviepy)
         if self.type !='element':
-            rs = rs.set_position((self.position['x'], self.position['y']))
+          rs = rs.set_position((self.position['x'], self.position['y']))
         if self.duration > 0:
             rs = rs.set_duration(self.duration).crossfadeout(0.5)
-        if self.duration > 0 and self.start_time > 0:
+        elif self.duration < 0:
+            rs = rs.set_duration(1200)
+
+        if self.start_time > 0:
             rs = rs.set_start(self.start_time).crossfadein(0.5)
-        if self.duration < 0 and self.start_time > 0:
-            rs = rs.set_duration(1200).set_start(self.start_time).crossfadein(0.5)
+        if self.start_time == 0:
+            rs = rs.set_start(self.start_time)
         if self.type !='element' and self.position['rotation'] != 0:
             rs = rs.rotate(self.position['rotation'])
         self.rs=rs
@@ -403,7 +411,8 @@ class VideoComp(Component):
         if self.ext == "gif":
             has_mask= True
             self.video_path = FFmpeg.convert_gif(self.video_path)
-
+        if self.ext == "mov":
+            has_mask = True
         rs = VideoFileClip(self.video_path, audio=not self.isMute, has_mask=has_mask)
         self.real_duration = rs.duration
         if (self.index == 0 or self.isLoop) and rs.duration < 1200: #max 20 mins loop
